import matplotlib
# font = {'family': 'arial', 'size': 14}
# matplotlib.rc('font', **font)
# TODO: fix pixel corner coords properly
matplotlib.rcParams['pcolor.shading'] = 'auto'
